@@ -29,13 +29,19 @@
 #include "slog.h"
 #include "global.h"
 
-#define DEFAULT_REKEY		3600
-#define DEFAULT_KEEPALIVE	60	// one keepalive/minute (it's just 8 bytes...)
-#define DEFAULT_UDPPORT		655	// same as tinc, conflicts would be rare
-#define DEFAULT_MTU		1500	// let's ether-net
-#define DEFAULT_MAX_RETRY	3600	// retry at least this often
+#define DEFAULT_REKEY	       		3600
+#define DEFAULT_KEEPALIVE      		60	// one keepalive/minute (it's just 8 bytes...)
+#define DEFAULT_UDPPORT	       		655	// same as tinc, conflicts would be rare
+#define DEFAULT_MTU	       		1500	// let's ether-net
+#define DEFAULT_MAX_RETRY      		3600	// retry at least this often
+ 
+#define DEFAULT_DNS_TIMEOUT_FACTOR	8.F	// initial retry timeout multiple
+#define DEFAULT_DNS_SEND_INTERVAL	.01F	// minimum send interval
+#define DEFAULT_DNS_OVERLAP_FACTOR	.5F	// RTT * LATENCY_FACTOR == sending rate
+#define DEFAULT_DNS_MAX_OUTSTANDING	100	// max. number of outstanding requests
 
-enum {
+enum
+{
   PROT_UDPv4  = 0x01, // udp over ipv4
   PROT_IPv4   = 0x02, // generic ip protocol
   PROT_TCPv4  = 0x04, // tcp over ipv4 (server)
@@ -50,12 +56,14 @@ enum {
 u8 best_protocol (u8 protset);
 const char *strprotocol (u8 protocol);
 
-struct conf_node {
+struct conf_node
+{
   int id;         // the id of this node, a 12-bit-number
 
   RSA *rsa_key;   // his public key
   char *nodename; // nodename, an internal nickname.
   char *hostname; // hostname, if known, or NULL.
+  char *if_up_data;
 #if ENABLE_DNS
   char *domain;   // dns tunnel domain
 #endif
@@ -77,7 +85,8 @@ struct conf_node {
   ~conf_node ();
 };
 
-struct configuration {
+struct configuration
+{
   typedef vector<conf_node *> node_vector;
   node_vector nodes;
   conf_node default_node;
@@ -109,12 +118,15 @@ struct configuration {
 #if ENABLE_DNS
   char *dns_forw_host;
   u16 dns_forw_port;
+  float dns_timeout_factor;
+  float dns_send_interval;
+  float dns_overlap_factor;
+  int dns_max_outstanding;
 #endif
 
   void init ();
   void cleanup ();
-  void read_config (bool need_keys);
-  void clear_config ();
+  void clear ();
 
   // create a filename from string, replacing %s by the nodename
   // and using relative paths under confbase.
@@ -126,6 +138,22 @@ struct configuration {
   ~configuration ();
 };
 
+struct configuration_parser
+{
+  configuration &conf;
+
+  bool need_keys;
+  conf_node *node;
+
+  int argc;
+  char **argv;
+
+  configuration_parser (configuration &conf, bool need_keys, int argc, char **argv);
+
+  const char *parse_line (char *line);
+  void parse_argv ();
+};
+
 extern struct configuration conf;
 
 #define THISNODE ::conf.thisnode
