@@ -32,12 +32,12 @@
 #include "iom.h"
 
 /*
- * check for an existing vped for this net, and write pid to pidfile
+ * check for an existing gvpe for this net, and write pid to pidfile
  */
 extern int write_pidfile (void);
 
 /*
- * kill older vped
+ * kill older gvpe
  */
 extern int kill_other (int signal);
 
@@ -112,7 +112,7 @@ struct sliding_window {
 typedef callback0<const char *> run_script_cb;
 
 // run a shell script (or actually an external program).
-void run_script (const run_script_cb &cb, bool wait);
+bool run_script (const run_script_cb &cb, bool wait);
 
 #if ENABLE_HTTP_PROXY
 u8 *base64_encode (const u8 *data, unsigned int len);
